@@ -15,7 +15,7 @@ use vars qw($VERSION);
 use Data::RecordStore;
 use Data::ObjectStore::Cache;
 
-$VERSION = '2.10';
+$VERSION = '2.11';
 
 our $DEBUG = 0;
 our $UPGRADING;
@@ -316,10 +316,7 @@ sub save {
     }
     my $node = $self->_fetch_store_info_node;
     my $now = time;
-
-    unless( $self->[OPTIONS]{NO_TRANSACTIONS} ) {
-        $self->[DATA_PROVIDER]->use_transaction;
-    }
+    $self->[DATA_PROVIDER]->use_transaction;
 
     my( @dirty ) = keys %{$self->[DIRTY]};
     
@@ -338,9 +335,7 @@ sub save {
     $node->set_last_update_time( $now );
     $self->_save( $node );
 
-    unless( $self->[OPTIONS]{NO_TRANSACTIONS} ) {
-        $self->[DATA_PROVIDER]->commit_transaction;
-    }
+    $self->[DATA_PROVIDER]->commit_transaction;
     $self->[DIRTY] = {};
     return 1;
 } #save
@@ -516,7 +511,7 @@ sub fetch {
       };
       if( $@ ) {
           if( $force ) {
-              warn "Forcing '$class' to be 'Data::ObjectStore::Container'";
+              warn "warn '$class' to be 'Data::ObjectStore::Container'";
               $class = 'Data::ObjectStore::Container';
           } else {
               die $@;
